==> aliyun-python-sdk-computenestsupplier-1.0.1.tar.gz: aliyun-python-sdk-computenestsupplier-1.0.1/aliyunsdkcomputenestsupplier/request/v20210521/GetArtifactRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcomputenestsupplier.endpoint import endpoint_data

class GetArtifactRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ComputeNestSupplier', '2021-05-21', 'GetArtifact')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ArtifactVersion(self): # String
		return self.get_query_params().get('ArtifactVersion')

	def set_ArtifactVersion(self, ArtifactVersion):  # String
		self.add_query_param('ArtifactVersion', ArtifactVersion)
	def get_ArtifactId(self): # String
		return self.get_query_params().get('ArtifactId')

	def set_ArtifactId(self, ArtifactId):  # String
		self.add_query_param('ArtifactId', ArtifactId)

==> aliyun-python-sdk-computenestsupplier-1.0.5.tar.gz: aliyun-python-sdk-computenestsupplier-1.0.5/aliyunsdkcomputenestsupplier/request/v20210521/GetArtifactRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcomputenestsupplier.endpoint import endpoint_data

class GetArtifactRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ComputeNestSupplier', '2021-05-21', 'GetArtifact')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ArtifactVersion(self): # String
		return self.get_query_params().get('ArtifactVersion')

	def set_ArtifactVersion(self, ArtifactVersion):  # String
		self.add_query_param('ArtifactVersion', ArtifactVersion)
	def get_ArtifactName(self): # String
		return self.get_query_params().get('ArtifactName')

	def set_ArtifactName(self, ArtifactName):  # String
		self.add_query_param('ArtifactName', ArtifactName)
	def get_ArtifactId(self): # String
		return self.get_query_params().get('ArtifactId')

	def set_ArtifactId(self, ArtifactId):  # String
		self.add_query_param('ArtifactId', ArtifactId)
